@@ -12,6 +12,7 @@ class Job:
     self.kwargs = kwargs
     self.result = None
     self.logger = None
+    self.channel = None
     self.verbosity = "error"
 
     if "logger" in kwargs:
@@ -20,6 +21,9 @@ class Job:
     if "verbosity" in kwargs:
       self.setVerbosity(kwargs["verbosity"])
 
+    if "channel" in kwargs:
+      self.channel = kwargs["channel"]
+
   def data(self):
     return self.payload
 
