@@ -43,7 +43,9 @@ def parse_args():
   worker.add_argument('-m', '--modules', dest='modules', action="append", type=str, default=[], help='additional python module paths')
   worker.add_argument('-b', '--heartbeat', dest='heartbeat', type=int, default=1,  help='worker heart beat in seconds (default: 1)')
   worker.add_argument('--logger', dest='logger', type=str, default=None,  help='logger callback function (default: None)')
+  worker.add_argument('--log-file', dest='log_file', type=str, default=None,  help='path to log file (default: None)')
   worker.add_argument('--verbosity', dest='verbosity', type=str, default="error",  help='logger verbosity, options are [error, completed, progress] (default: error)')
+  worker.add_argument('-e', '--executable', dest='executables', action=UpdateAction, type=dict_load, default={},  help='python executable paths for running job based on channels.')
 
   queue = subparsers.add_parser('queue', description='Schedule a job into the job queue')
   queue.add_argument('function_name', metavar='function_name', type=str, help='the full name of the entry point function')
@@ -108,7 +110,7 @@ def run_worker(args):
     for module in args.modules:
       sys.path.append(os.path.abspath(module))
 
-    worker = Worker(queues, heart_beat=args.heartbeat, logger=args.logger, verbosity=args.verbosity)
+    worker = Worker(queues, heart_beat=args.heartbeat, logger=args.logger, verbosity=args.verbosity, executables=args.executables, logFile=args.log_file)
     if (channels is None) or len(channels) == 0:
       print(f"**Started worker with heart beat of {args.heartbeat} second(s)", flush=True)
     else:
