@@ -1,13 +1,27 @@
 from .queue import Queue
 from .job import Job
-from typing import Type, Union, Tuple, Callable
+from .utils import executionCode
+from typing import Dict, Type, Union, Tuple, Callable
 from time import sleep
-from threading import Thread
 import importlib
+import subprocess
+import sys, json
+from bson import json_util
+
+def run_with_executable(function_name, executable=None, args=[], kwargs={}, stdout=None):
+  if executable is None:
+    executable = sys.executable
+
+  data = {"function_name": function_name, "args": args, "kwargs": kwargs, "stdout": stdout}
+  result = subprocess.run([executable, "-c", executionCode], stdout=subprocess.PIPE, input=str.encode(json.dumps(data, default=json_util.default)))
+  out = result.stdout.decode().split("\n")
+  if len(out) > 0:
+    output = json.loads(out[-1], object_hook=json_util.object_hook)
+    return output
 
 class Worker:
 
-  def __init__(self, queues: Union[Tuple[Queue,...], Type[Queue]], channel: Union[Tuple[str,...], str]=None, heart_beat: int = 1, verbosity: str = "error", logger: Union[str, Callable] = None ) -> None:
+  def __init__(self, queues: Union[Tuple[Queue,...], Type[Queue]], channel: Union[Tuple[str,...], str]=None, heart_beat: int = 1, verbosity: str = "error", logger: Union[str, Callable] = None, executables: Dict = None, logFile: str = None) -> None:
     
     if isinstance(queues, tuple) or isinstance(queues, list):
       self.queues = queues
@@ -27,6 +41,15 @@ class Worker:
 
     self._verbosity = verbosity
     self.setLogger(logger)
+
+    self.logFile = None
+    if not logFile is None:
+      self.logFile = logFile
+
+    if not executables is None and isinstance(executables, dict):
+      self.executables = executables
+    else:
+      self.executables = {}
     
   def setLogger(self, logger: Union[str, Callable]):
     if callable(logger):
@@ -72,9 +95,7 @@ class Worker:
           break
 
     if not job is None:
-      self.thread = Thread(target=self._run_job, kwargs={'job': job})
-      self.thread.start()
-      self.thread.join()
+      self._run_job(job)
       self._working = False
     else:
       self._working = False
@@ -86,23 +107,28 @@ class Worker:
     try:
       if not payload is None:
         callback = payload.get("function_name")
+
         if not callback is None:
-          if str(callback).__contains__("."):
-            mod_name, func_name = callback.rsplit(".", 1)
-            mod = importlib.import_module(mod_name)
-            func = getattr(mod, func_name)
-            args = payload.get("args", [])
-            kwargs = payload.get("kwargs", {})
-            result = func(*args, **kwargs)
-            job.complete(result)
-          elif callback in globals():
-            func = globals()[callback]
-            args = payload.get("args", [])
-            kwargs = payload.get("kwargs", {})
-            result = func(*args, **kwargs)
-            job.complete(result)
-          else:
-            job.error(f"Function {callback} not found!")
+          args = payload.get("args", [])
+          kwargs = payload.get("kwargs", {})
+          executable = None
+          channel = job.channel
+
+          if not channel is None:
+            if channel in self.executables:
+              executable = self.executables[channel]
+
+          output = run_with_executable(callback, args=args, kwargs=kwargs, executable=executable, stdout=self.logFile)
+
+          if not output is None:
+            if "result" in output:
+              job.complete(output["result"])
+            if "error" in output:
+              print(output["error"])
+              job.error(output["error"])
+        else:
+          job.error(f"Error: no callback funtion specified for job!")
+          print(f"Error: no callback funtion specified for job!")
 
     except Exception as ex:
       job.error(f"Error: {ex}")
